@@ -3,12 +3,12 @@ c         special purpose such as to see the scattering effect
 c         by putting  Es = 0.
 
        namelist  /HParam/
-     +  AnihiE, BackAngLimit, BaseErg, BasePower, BorderHeightH
-     +, BorderHeightL, Cekaon, Ceneuc, Cepic0, Charge2heavyG
-     +, Code2heavyG, Code2massN, Deltkp, Deltpip, Deltpp, Ecrit, Efermi
-     +, Elund, Elund2, Elund3, EndLevel, EndLevel2, ErrorOut, Es
-     +, Eta2Pi0, EthinRatio, EventNo, EventsInTheRun, ExactThick
-     +, FragmentTbl, Generate2, HeavyG2charge, HeavyG2code
+     +  AnihiE, AtmosFile, BackAngLimit, BaseErg, BasePower
+     +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
+     +, Charge2heavyG, Code2heavyG, Code2massN, Deltkp, Deltpip, Deltpp
+     +, Ecrit, Efermi, Elund, Elund2, Elund3, EndLevel, EndLevel2
+     +, ErrorOut, Es, Eta2Pi0, EthinRatio, EventNo, EventsInTheRun
+     +, ExactThick, FragmentTbl, Generate2, HeavyG2charge, HeavyG2code
      +, HeavyG2massN, HeavyG2symbol, HowGeomag, HowIntNuc
      +, InclusiveFile, IncreaseXsec, KEminObs2, Knockon, Kpicns, Kpilog
      +, LpmBremEmin, LpmPairEmin, LundPara, MagBrem, MagBremEmin
